{
  pkgs,
  lib,
  ...
}: let
  common = pkgs.callPackage ./common.nix {};
in
  pkgs.writeShellScriptBin "deploy" ''
    ${common}

    echo_header "Deploying"

    setup_go_env

    if [ -z "''$CI_JOB_TOKEN" ]; then
        echo_fail "Error: CI_JOB_TOKEN variable is not set."
        exit 1
    fi

    if [ -z "''${CI_REPOSITORY_URL}" ]; then
        echo_fail "Error: CI_REPOSITORY_URL environment variable is not set."
        exit 1
    fi

    if [ -z "''${CI_PROJECT_DIR}" ]; then
        echo_fail "Error: CI_PROJECT_DIR environment variable is not set."
        exit 1
    fi

    cd ''${CI_PROJECT_DIR} || exit 1

    ${pkgs.git}/bin/git config --global user.email "''${GITLAB_USER_EMAIL}"
    ${pkgs.git}/bin/git config --global user.name "''${GITLAB_USER_NAME:-"Gitlab CI"}"
    ${pkgs.git}/bin/git config --global credential.helper '!f() { echo "username=gitlab-ci-token"; echo "password=''${CI_JOB_TOKEN}"; }; f'
    ${pkgs.git}/bin/git config --global pull.rebase true
    ${pkgs.git}/bin/git config --global http.sslVerify "false"

    ${pkgs.git}/bin/git remote set-url origin https://pad:''${GITLAB_TOKEN}@''${CI_REPOSITORY_URL#*@}

    ${pkgs.git}/bin/git fetch --all --tags --unshallow
    ${pkgs.git}/bin/git reset --hard origin/master
    ${pkgs.git}/bin/git clean -fd
    ${pkgs.git}/bin/git checkout $CI_COMMIT_REF_NAME
    ${pkgs.git}/bin/git pull origin $CI_COMMIT_REF_NAME

    if ! ${pkgs.git}/bin/git --no-pager log --decorate=short --pretty=oneline -n 30
    then
        echo_fail "Error: Could not get git log."
        exit 1
    fi

    ${pkgs.git}/bin/git fetch --prune --prune-tags

    echo_step "Bumping version"
    gitVersion=$(version predict --exit-code-if-no-bump)
    if [ -z "$gitVersion" ]; then
        echo_ok "There is no version bump."
        echo_ok "done"
        exit 0
    fi
    
    gitVersion="v$gitVersion"
    
    ${pkgs.git}/bin/git tag -a $gitVersion -m"chore: bump version"
    ${pkgs.git}/bin/git --no-pager log --decorate=short --pretty=oneline -n 5
    ${pkgs.git}/bin/git push -o ci.skip origin ''${CI_COMMIT_REF_NAME} --tags

    echo_ok "done"
  ''
